﻿using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Petzold.Phone.EBookReader;

namespace HorrorReader
{
    public partial class AnnotationsPage : PhoneApplicationPage
    {
        BookInfo book = (Application.Current as App).CurrentBook;
        Popup activePopup;
        string saveNote;

        public AnnotationsPage()
        {
            InitializeComponent();
            this.DataContext = book;
        }

        protected override void OnNavigatedFrom(NavigationEventArgs args)
        {
            if (activePopup != null)
            {
                this.State["popup"] = activePopup.Name;
                this.State["popupOffsetX"] = activePopup.HorizontalOffset;
                this.State["popupOffsetY"] = activePopup.VerticalOffset;
                ITombstonable popupChild = activePopup.Child as ITombstonable;

                if (popupChild != null)
                    popupChild.SaveState(activePopup.Name, this.State);
            }
            else if (this.State.ContainsKey("popup"))
            {
                this.State.Remove("popup");
            }

            base.OnNavigatedFrom(args);
        }

        protected override void OnNavigatedTo(NavigationEventArgs args)
        {
            if (activePopup == null && this.State.ContainsKey("popup"))
            {
                activePopup = this.FindName(this.State["popup"] as string) as Popup;
                activePopup.HorizontalOffset = (double)this.State["popupOffsetX"];
                activePopup.VerticalOffset = (double)this.State["popupOffsetY"];
                ITombstonable popupChild = activePopup.Child as ITombstonable;

                if (popupChild != null)
                    popupChild.RestoreState(activePopup.Name, this.State);

                annotationsListBox.IsEnabled = false;
                activePopup.IsOpen = true;
            }

            base.OnNavigatedTo(args);
        }

        protected override void OnBackKeyPress(CancelEventArgs args)
        {
            if (activePopup != null)
            {
                activePopup.IsOpen = false;
                activePopup = null;
                annotationsListBox.IsEnabled = true;
                args.Cancel = true;
            }

            base.OnBackKeyPress(args);
        }

        void OnAnnotationsListBoxSelectionChanged(object sender, SelectionChangedEventArgs args)
        {
            Annotation annotation = annotationsListBox.SelectedItem as Annotation;

            if (annotation != null)
            {
                book.IsChapterAndPageInvalid = true;
                book.CurrentCharacterOffset = annotation.CharacterOffset;
                this.NavigationService.GoBack();
            }
        }

        void OnEditButtonClick(object sender, RoutedEventArgs args)
        {
            Button btn = sender as Button;
            Annotation annotation = btn.Tag as Annotation;

            saveNote = annotation.Note;
            annotationDialog.Annotation = annotation;
            annotationsListBox.IsEnabled = false;
            annotationDialogPopup.IsOpen = true;
            activePopup = annotationDialogPopup;
        }

        void OnAnnotationDialogDismissed(object sender, CancelEventArgs args)
        {
            AnnotationDialog annotationDialog = sender as AnnotationDialog;

            // See BookmarksPage.xaml.cs for the following logic.
            if (args.Cancel)
            {
                annotationDialog.Annotation.Note = saveNote;
            }
            else
            {
                int index = book.Annotations.IndexOf(annotationDialog.Annotation);
                book.Annotations[index] = annotationDialog.Annotation;
            }

            annotationDialogPopup.IsOpen = false;
            annotationsListBox.IsEnabled = true;
            activePopup = null;
        }

        void OnDeleteButtonClick(object sender, RoutedEventArgs args)
        {
            Button btn = sender as Button;
            Annotation annotation = btn.Tag as Annotation;
            deleteConfirmDialog.Message = annotation.Note;
            annotationsListBox.IsEnabled = false;
            deleteConfirmDialog.Tag = annotation;
            deleteConfirmDialogPopup.IsOpen = true;
            activePopup = deleteConfirmDialogPopup;
        }

        void OnDeleteConfirmDialogDismissed(object sender, CancelEventArgs args)
        {
            if (!args.Cancel)
            {
                OkCancelDialog dlg = sender as OkCancelDialog;
                Annotation annotation = dlg.Tag as Annotation;
                book.Annotations.Remove(annotation);
            }

            deleteConfirmDialogPopup.IsOpen = false;
            annotationsListBox.IsEnabled = true;
            activePopup = null;
        }
    }
}