﻿using System;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Petzold.Phone.EBookReader;

namespace HorrorReader
{
    public partial class BookmarksPage : PhoneApplicationPage
    {
        BookInfo book = (Application.Current as App).CurrentBook;
        Popup activePopup;
        string saveLabel;

        public BookmarksPage()
        {
            InitializeComponent();
            this.DataContext = book;
        }

        protected override void OnNavigatedFrom(NavigationEventArgs args)
        {
            if (activePopup != null)
            {
                this.State["popup"] = activePopup.Name;
                this.State["popupOffsetX"] = activePopup.HorizontalOffset;
                this.State["popupOffsetY"] = activePopup.VerticalOffset;
                ITombstonable popupChild = activePopup.Child as ITombstonable;

                if (popupChild != null)
                    popupChild.SaveState(activePopup.Name, this.State);
            }
            else if (this.State.ContainsKey("popup"))
            {
                this.State.Remove("popup");
            }

            base.OnNavigatedFrom(args);
        }

        protected override void OnNavigatedTo(NavigationEventArgs args)
        {
            if (activePopup == null && this.State.ContainsKey("popup"))
            {
                activePopup = this.FindName(this.State["popup"] as string) as Popup;
                activePopup.HorizontalOffset = (double)this.State["popupOffsetX"];
                activePopup.VerticalOffset = (double)this.State["popupOffsetY"];
                ITombstonable popupChild = activePopup.Child as ITombstonable;

                if (popupChild != null)
                    popupChild.RestoreState(activePopup.Name, this.State);

                bookmarksListBox.IsEnabled = false;
                activePopup.IsOpen = true;
            }

            base.OnNavigatedTo(args);
        }

        protected override void OnBackKeyPress(CancelEventArgs args)
        {
            if (activePopup != null)
            {
                activePopup.IsOpen = false;
                activePopup = null;
                bookmarksListBox.IsEnabled = true;
                args.Cancel = true;
            }

            base.OnBackKeyPress(args);
        }

        void OnBookmarksListBoxSelectionChanged(object sender, SelectionChangedEventArgs args)
        {
            Bookmark bookmark = bookmarksListBox.SelectedItem as Bookmark;

            if (bookmark != null)
            {
                book.IsChapterAndPageInvalid = true;
                book.CurrentCharacterOffset = bookmark.CharacterOffset;
                this.NavigationService.GoBack();
            }
        }

        void OnEditButtonClick(object sender, RoutedEventArgs args)
        {
            Button btn = sender as Button;
            Bookmark bookmark = btn.Tag as Bookmark;

            saveLabel = bookmark.Label;
            bookmarkDialog.Bookmark = bookmark;
            bookmarksListBox.IsEnabled = false;
            bookmarkDialogPopup.IsOpen = true;
            activePopup = bookmarkDialogPopup;
        }

        void OnBookmarkDialogDismissed(object sender, CancelEventArgs args)
        {
            BookmarkDialog bookmarkDialog = sender as BookmarkDialog;

            // If the page has been tombstoned, the Bookmark object from 
            //  the dialog box is not the same object that was set to it in
            //  the OnEditButtonClick method, and not the same as the 
            //  corresponding object in the collection.
            
            // Fortunately, Bookmark implements IEquatable<T>, so we can 
            //  find the matching Bookmark object in the Bookmarks collection.

            if (args.Cancel)
            {
                // This is good if the page hasn't been tombstoned;
                //  the saved label is restored to the single Bookmark object.
                // If the page has been tombstoned, nothing much happens
                bookmarkDialog.Bookmark.Label = saveLabel;
            }
            else
            {
                // If the page hasn't been tombstoned, nothing needs to
                //  be done here. But let's do the tombstoning logic to
                //  get the new Bookmark in the collection.
                int index = book.Bookmarks.IndexOf(bookmarkDialog.Bookmark);
                book.Bookmarks[index] = bookmarkDialog.Bookmark;
            }

            bookmarkDialogPopup.IsOpen = false;
            bookmarksListBox.IsEnabled = true;
            activePopup = null;
        }

        void OnDeleteButtonClick(object sender, RoutedEventArgs args)
        {
            Button btn = sender as Button;
            Bookmark bookmark = btn.Tag as Bookmark;
            deleteConfirmDialog.Message = bookmark.Label;
            bookmarksListBox.IsEnabled = false;
            deleteConfirmDialog.Tag = bookmark;
            deleteConfirmDialogPopup.IsOpen = true;
            activePopup = deleteConfirmDialogPopup;
        }

        void OnDeleteConfirmDialogDismissed(object sender, CancelEventArgs args)
        {
            if (!args.Cancel)
            {
                OkCancelDialog dlg = sender as OkCancelDialog;
                Bookmark bookmark = dlg.Tag as Bookmark;
                book.Bookmarks.Remove(bookmark);
            }

            deleteConfirmDialogPopup.IsOpen = false;
            bookmarksListBox.IsEnabled = true;
            activePopup = null;
        }
    }
}