﻿using System;
using System.IO;
using System.IO.IsolatedStorage;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Petzold.Phone.EBookReader;

namespace HorrorReader
{
    public partial class MainPage : PhoneApplicationPage
    {
        public MainPage()
        {
            InitializeComponent();
        }

        void OnButtonClick(object sender, RoutedEventArgs args)
        {
            // Button.Content is book's friendly title
            // Button.Tag is the book's filename
            Button btn = sender as Button;
            string bookFilename = btn.Tag as string;
            string infoFilename = Path.ChangeExtension(bookFilename, ".info");
            BookInfo book = BookInfo.Load(infoFilename);

            // The BookInfo object will be null if the book has never been loaded 
            //      and hence doesn't yet exist in isolated storage.
            // The BookInfo must be created from the raw Project Gutenberg text file.
            if (book == null)
            {
                byte[] buffer = null;

                // Transfer from resource to isolated storage
                using (Stream stream = Application.GetResourceStream(new Uri("Books/" + bookFilename, UriKind.Relative)).Stream)
                {
                    buffer = new byte[stream.Length];
                    stream.Read(buffer, 0, buffer.Length);
                }
                using (IsolatedStorageFile isoStorage = IsolatedStorageFile.GetUserStoreForApplication())
                {
                    using (IsolatedStorageFileStream stream = isoStorage.CreateFile(bookFilename))
                    {
                        stream.Write(buffer, 0, buffer.Length);
                    }
                }

                // Create new BookInfo object
                book = new BookInfo(infoFilename, bookFilename, btn.Content as string);

                // This shouldn't be necessary, but problems will result if it never gets saved
                book.Save();
            }

            // Store BookInfo object in App.CurrentBook property for reference by all pages
            (Application.Current as App).CurrentBook = book;

            // Navigate to the BookViewerPage
            this.NavigationService.Navigate(new Uri("/BookViewerPage.xaml", UriKind.Relative));
        }

        protected override void OnNavigatedTo(NavigationEventArgs args)
        {
            BookInfo book = (Application.Current as App).CurrentBook;

            // If we're navigating back here, and App.CurrentBook is != null,
            //  then we're done reading that book for now, and the BookInfo 
            //  file needs to be saved.
            if (book != null)
            {
                book.Save();
                (Application.Current as App).CurrentBook = null;
            }
            base.OnNavigatedTo(args);
        }
    }
}