﻿using System;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Navigation;
using Microsoft.Phone.Controls;
using Petzold.Phone.EBookReader;

namespace HorrorReader
{
    public partial class SettingsPage : PhoneApplicationPage
    {
        AppSettings appSettings = (Application.Current as App).AppSettings;
        bool initializingTransitionButtons;

        public SettingsPage()
        {
            InitializeComponent();
            Loaded += (sender, args) =>
                {
                    fontFamilyListBox.SelectedItem = appSettings.FontFamily;
                    fontSizeSlider.Value = (int)(10 * appSettings.FontSizeMultiplier);
                    fontFamilyListBox.ScrollIntoView(fontFamilyListBox.SelectedItem);
                };
        }

        void OnLoadedPivotItem(object sender, PivotItemEventArgs e)
        {
            if (e.Item.Header as string == "transitions")
            {
                initializingTransitionButtons = true;

                foreach (UIElement child in transitionRadioButtonStack.Children)
                {
                    RadioButton radio = child as RadioButton;
                    radio.IsChecked = radio.Content as string == appSettings.PageTransition;
                }
                bookViewer.JumpToPage(0, 0);
                initializingTransitionButtons = false;
            }
        }

        protected override void OnNavigatedFrom(NavigationEventArgs arg)
        {
            appSettings.FontFamily = fontFamilyListBox.SelectedItem as string;
            appSettings.FontSizeMultiplier = fontSizeSlider.Value / 10.0;
            base.OnNavigatedFrom(arg);
        }

        void OnFontFamilyListBoxSelectionChanged(object sender, SelectionChangedEventArgs args)
        {
            PossiblyDisableDefaultsButton();
        }

        void OnFontSizeSliderValueChanged(object sender, RoutedPropertyChangedEventArgs<int> args)
        {
            PossiblyDisableDefaultsButton();
        }

        void PossiblyDisableDefaultsButton()
        {
            if (restoreDefaultsButton != null && fontFamilyListBox != null && fontSizeSlider != null)
            {
                restoreDefaultsButton.IsEnabled = (fontFamilyListBox.SelectedItem as string != AppSettings.DefaultFontFamily ||
                                                   fontSizeSlider.Value / 10.0 != AppSettings.DefaultFontSizeMultiplier);
            }
        }

        void OnRestoreDefaultsButtonClick(object sender, RoutedEventArgs args)
        {
            fontFamilyListBox.SelectedItem = AppSettings.DefaultFontFamily;
            fontSizeSlider.Value = (int)(10 * AppSettings.DefaultFontSizeMultiplier);
        }

        void OnTransitionRadioButtonChecked(object sender, RoutedEventArgs e)
        {
            RadioButton radio = sender as RadioButton;
            appSettings.PageTransition = radio.Content as string;

            switch (appSettings.PageTransition)
            {
                case "slide": bookViewer.PageTransition = new SlideTransition(); break;
                case "skew": bookViewer.PageTransition = new SkewTransition(); break;
                case "curl": bookViewer.PageTransition = new CurlTransition(); break;
                case "flip": bookViewer.PageTransition = new FlipTransition(); break;
            }
            if (!initializingTransitionButtons)
                bookViewer.AnimateToNextPage();
        }
    }
}