﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;

namespace Petzold.Phone.EBookReader
{
    public partial class AnnotationDialog : UserControl, ITombstonable
    {
        Annotation annotation;

        public static readonly DependencyProperty CaptionProperty =
            DependencyProperty.Register("Caption",
                typeof(string),
                typeof(AnnotationDialog),
                new PropertyMetadata(OnCaptionPropertyChanged));

        public event EventHandler<CancelEventArgs> DialogDismissed;

        public AnnotationDialog()
        {
            InitializeComponent();

            Loaded += (sender, args) =>
            {
                noteTextBox.Focus();
            };
        }

        public Annotation Annotation
        {
            set
            {
                annotation = value;
                textTextBox.Text = annotation.Text;
                noteTextBox.Text = annotation.Note;
                noteTextBox.Select(noteTextBox.Text.Length, 0);
            }
            get
            {
                return annotation;
            } 
        }

        public string Caption
        {
            set { SetValue(CaptionProperty, value); }
            get { return (string)GetValue(CaptionProperty); }
        }

        public void SaveState(string prefix, IDictionary<string, object> state)
        {
            state[prefix + "annotation"] = this.Annotation;
            state[prefix + "text"] = textTextBox.Text;
            state[prefix + "note"] = noteTextBox.Text;
            state[prefix + "selectionStart"] = noteTextBox.SelectionStart;
            state[prefix + "selectionLength"] = noteTextBox.SelectionLength;
        }

        public void RestoreState(string prefix, IDictionary<string, object> state)
        {
            this.Annotation = state[prefix + "annotation"] as Annotation;
            textTextBox.Text = state[prefix + "text"] as string;
            noteTextBox.Text = state[prefix + "note"] as string;
            noteTextBox.SelectionStart = (int)state[prefix + "selectionStart"];
            noteTextBox.SelectionLength = (int)state[prefix + "selectionLength"];
        }

        static void OnCaptionPropertyChanged(DependencyObject obj, DependencyPropertyChangedEventArgs args)
        {
            (obj as AnnotationDialog).captionTextBlock.Text = args.NewValue as string;
        }

        void OnCancelButtonClick(object sender, RoutedEventArgs args)
        {
            if (DialogDismissed != null)
                DialogDismissed(this, new CancelEventArgs(true));
        }

        void OnOkButtonClick(object sender, RoutedEventArgs args)
        {
            this.Annotation.Note = noteTextBox.Text;

            if (DialogDismissed != null)
                DialogDismissed(this, new CancelEventArgs());
        }
    }
}
