﻿using System;
using System.ComponentModel;
using System.IO;
using System.IO.IsolatedStorage;
using System.Xml.Serialization;

namespace Petzold.Phone.EBookReader
{
    public class AppSettings
    {
        public static string DefaultFontFamily = "Segoe WP";
        public static double MinimumFontSizeMultiplier = 0.5;
        public static double MaximumFontSizeMultiplier = 2;
        public static double DefaultFontSizeMultiplier = 1;

        public AppSettings()
        {
            this.FontFamily = DefaultFontFamily;
            this.FontSizeMultiplier = DefaultFontSizeMultiplier;
            this.PageTransition = "slide";
        }

        public string FontFamily { set; get; }

        public double FontSizeMultiplier { set; get; }

        public string PageTransition { set; get; }

        public static AppSettings Load(string filename)
        {
            AppSettings appSettings = null;

            using (IsolatedStorageFile storage = IsolatedStorageFile.GetUserStoreForApplication())
            {
                if (storage.FileExists(filename))
                {
                    using (IsolatedStorageFileStream stream = storage.OpenFile(filename, FileMode.Open, FileAccess.Read))
                    {
                        XmlSerializer serializer = new XmlSerializer(typeof(AppSettings));
                        appSettings = serializer.Deserialize(stream) as AppSettings;
                    }
                }
                else
                {
                    appSettings = new AppSettings();
                }
            }
            return appSettings;
        }

        public void Save(string filename)
        {
            using (IsolatedStorageFile storage = IsolatedStorageFile.GetUserStoreForApplication())
            {
                using (IsolatedStorageFileStream stream = storage.OpenFile(filename, FileMode.Create, FileAccess.Write))
                {
                    XmlSerializer serializer = new XmlSerializer(typeof(AppSettings));
                    serializer.Serialize(stream, this);
                }
            }
        }
    }
}
