﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;

namespace Petzold.Phone.EBookReader
{
    public partial class BookmarkDialog : UserControl, ITombstonable
    {
        Bookmark bookmark;

        public static readonly DependencyProperty CaptionProperty =
            DependencyProperty.Register("Caption",
                typeof(string),
                typeof(BookmarkDialog),
                new PropertyMetadata(OnCaptionPropertyChanged));

        public event EventHandler<CancelEventArgs> DialogDismissed;

        public BookmarkDialog()
        {
            InitializeComponent();

            Loaded += (sender, args) =>
            {
                labelTextBox.Focus();
            };
        }

        public Bookmark Bookmark
        {
            set
            {
                bookmark = value;
                labelTextBox.Text = bookmark.Label;
                labelTextBox.Select(labelTextBox.Text.Length, 0);
            }
            get
            {
                return bookmark;
            } 
        }

        public string Caption
        {
            set { SetValue(CaptionProperty, value); }
            get { return (string)GetValue(CaptionProperty); }
        }

        public void SaveState(string prefix, IDictionary<string, object> state)
        {
            state[prefix + "bookmark"] = this.Bookmark;
            state[prefix + "text"] = labelTextBox.Text;
            state[prefix + "selectionStart"] = labelTextBox.SelectionStart;
            state[prefix + "selectionLength"] = labelTextBox.SelectionLength;
        }

        public void RestoreState(string prefix, IDictionary<string, object> state)
        {
            this.Bookmark = state[prefix + "bookmark"] as Bookmark;
            labelTextBox.Text = state[prefix + "text"] as string;
            labelTextBox.SelectionStart = (int)state[prefix + "selectionStart"];
            labelTextBox.SelectionLength = (int)state[prefix + "selectionLength"];
        }

        static void OnCaptionPropertyChanged(DependencyObject obj, DependencyPropertyChangedEventArgs args)
        {
            (obj as BookmarkDialog).captionTextBlock.Text = args.NewValue as string;
        }

        void OnCancelButtonClick(object sender, RoutedEventArgs args)
        {
            if (DialogDismissed != null)
                DialogDismissed(this, new CancelEventArgs(true));
        }

        void OnOkButtonClick(object sender, RoutedEventArgs args)
        {
            this.Bookmark.Label = labelTextBox.Text;

            if (DialogDismissed != null)
                DialogDismissed(this, new CancelEventArgs());
        }

        void OnLabelTextBoxTextChanged(object sender, TextChangedEventArgs args)
        {
            okButton.IsEnabled = (sender as TextBox).Text.Length > 0;
        }
    }
}
