﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.Primitives;

namespace Petzold.Phone.EBookReader
{
    public partial class FindDialog : UserControl, ITombstonable
    {
        public event EventHandler<CancelEventArgs> DialogDismissed;
        public event EventHandler<FindTextEventArgs> FindText;

        public FindDialog()
        {
            InitializeComponent();

            AllowFinds();

            Loaded += (sender, args) =>
                {
                    if (whatTextBox.Text.Length == 0)
                        whatTextBox.Focus();
                };
        }

        public void SaveState(string prefix, IDictionary<string, object> state)
        {
            state[prefix + "what"] = whatTextBox.Text;
            state[prefix + "matchCase"] = matchCaseCheckBox.IsChecked.Value;
            state[prefix + "wholeWord"] = wholeWordCheckBox.IsChecked.Value;
            state[prefix + "goUp"] = goUpRadioButton.IsChecked.Value;
        }

        public void RestoreState(string prefix, IDictionary<string, object> state)
        {
            whatTextBox.Text = state[prefix + "what"] as string;
            matchCaseCheckBox.IsChecked = (bool)state[prefix + "matchCase"];
            wholeWordCheckBox.IsChecked = (bool)state[prefix + "wholeWord"];
            goUpRadioButton.IsChecked = (bool)state[prefix + "goUp"];
        }

        public void ShowNoMoreFinds()
        {
            buttonHider.Visibility = Visibility.Visible;
            findButton.IsEnabled = false;
        }

        void AllowFinds()
        {
            if (buttonHider != null)
                buttonHider.Visibility = Visibility.Collapsed;

            if (findButton != null)
                findButton.IsEnabled = whatTextBox.Text.Length > 0;
        }

        // Move popup to top when the TextBox gets focus
        void OnTextBoxGotFocus(object sender, RoutedEventArgs args)
        {
            Popup popup = this.Parent as Popup;

            if (popup != null)
                popup.VerticalOffset = 0;
        }

        void OnTextBoxTextChanged(object sender, TextChangedEventArgs args)
        {
            AllowFinds();
        }

        void OnButtonRedefineSearch(object sender, RoutedEventArgs args)
        {
            AllowFinds();
        }

        void OnFindButtonClick(object sender, RoutedEventArgs args)
        {
            if (FindText != null)
            {
                FindTextEventArgs evtArgs = new FindTextEventArgs
                {
                    Text = whatTextBox.Text,
                    MatchCase = matchCaseCheckBox.IsChecked.Value,
                    WholeWord = wholeWordCheckBox.IsChecked.Value,
                    GoUp = goUpRadioButton.IsChecked.Value,
                };
                FindText(this, evtArgs);
            }
        }

        void OnCancelButtonClick(object sender, RoutedEventArgs args)
        {
            if (DialogDismissed != null)
                DialogDismissed(this, new CancelEventArgs(true));
        }
    }
}
