﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;

namespace Petzold.Phone.EBookReader
{
    public partial class OkCancelDialog : UserControl, ITombstonable
    {
        public static readonly DependencyProperty TitleProperty =
            DependencyProperty.Register("Title",
                typeof(string),
                typeof(OkCancelDialog),
                new PropertyMetadata("", OnTitlePropertyChanged));

        public static readonly DependencyProperty MessageProperty =
            DependencyProperty.Register("Message",
                typeof(string),
                typeof(OkCancelDialog),
                new PropertyMetadata("", OnMessagePropertyChanged));

        public event EventHandler<CancelEventArgs> DialogDismissed;

        public OkCancelDialog()
        {
            InitializeComponent();
        }

        public string Title
        {
            set { SetValue(TitleProperty, value); }
            get { return (string)GetValue(TitleProperty); }
        }

        public string Message
        {
            set { SetValue(MessageProperty, value); }
            get { return (string)GetValue(MessageProperty); }
        }

        public void SaveState(string prefix, IDictionary<string, object> state)
        {
            state[prefix + "title"] = this.Title;
            state[prefix + "message"] = this.Message;
            state[prefix + "tag"] = this.Tag;
        }

        public void RestoreState(string prefix, IDictionary<string, object> state)
        {
            this.Title = state[prefix + "title"] as string;
            this.Message = state[prefix + "message"] as string;
            this.Tag = state[prefix + "tag"];
        }

        static void OnTitlePropertyChanged(DependencyObject obj, DependencyPropertyChangedEventArgs args)
        {
            (obj as OkCancelDialog).titleTextBlock.Text = args.NewValue as string;
        }

        static void OnMessagePropertyChanged(DependencyObject obj, DependencyPropertyChangedEventArgs args)
        {
            (obj as OkCancelDialog).messageTextBlock.Text = args.NewValue as string;
        }

        void OnCancelButtonClick(object sender, RoutedEventArgs args)
        {
            if (DialogDismissed != null)
                DialogDismissed(this, new CancelEventArgs(true));
        }

        void OnOkButtonClick(object sender, RoutedEventArgs args)
        {
            if (DialogDismissed != null)
                DialogDismissed(this, new CancelEventArgs());
        }
    }
}
